@@ -146,6 +146,15 @@ impl AppState {
         );
     }
 
+    pub fn cycle_name_sorting(&mut self, tree_view: &TreeView<'_>) {
+        self.sorting.toggle_name();
+        self.entries = tree_view.sorted_entries(
+            self.navigation().view_root,
+            self.sorting,
+            self.entry_check(),
+        );
+    }
+
     pub fn toggle_mtime_column(&mut self) {
         self.toggle_column(Column::MTime);
     }
@@ -244,8 +253,7 @@ impl AppState {
                         match self.delete_entry(entry_to_delete, tree_view) {
                             Ok(ed) => {
                                 entries_deleted += ed;
-                                self.message =
-                                    Some(format!("Deleted {} items...", entries_deleted));
+                                self.message = Some(format!("Deleted {entries_deleted} items..."));
                                 Ok(pane)
                             }
                             Err(c) => Err((pane, c)),
@@ -265,8 +273,7 @@ impl AppState {
                         match self.trash_entry(entry_to_trash, tree_view) {
                             Ok(ed) => {
                                 entries_trashed += ed;
-                                self.message =
-                                    Some(format!("Trashed {} items...", entries_trashed));
+                                self.message = Some(format!("Trashed {entries_trashed} items..."));
                                 Ok(pane)
                             }
                             Err(c) => Err((pane, c)),
