@@ -2,13 +2,14 @@ mod bytevis;
 mod common;
 mod eventloop;
 mod handlers;
-mod input;
+pub mod input;
 mod navigation;
+pub mod state;
+pub mod terminal;
 pub mod tree_view;
 
 pub use bytevis::*;
 pub use common::*;
-pub use eventloop::*;
 pub use handlers::*;
 
 #[cfg(test)]
